<?php
/**
 * Makena functions and definitions
 *
 * @package WordPress
 * @subpackage Mekana
 * @since Makena 1.0
 */

// Set up the content width value based on the theme's design and stylesheet.
if ( ! isset( $content_width ) )
	$content_width = 781;

/**
 * Makena setup.
 *
 * @since Makena 1.0
 */
function makena_setup() {
	
	load_theme_textdomain( 'makena' );

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// This theme supports a variety of post formats.
	add_theme_support( 'post-formats', array( 'image', 'quote' ) );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'makena' ) );
	register_nav_menu( 'secondary', __( 'Secondary Menu', 'makena' ) );
	register_nav_menu( 'footer', __( 'Footer Menu', 'makena' ) );
	register_nav_menu( 'mobile', __( 'Mobile Menu', 'makena' ) );

	/*
	 * This theme supports custom background color and image,
	 * and here we also set up the default background color.
	 */
	add_theme_support( 'custom-background', array(
		'default-color' => 'e6e6e6',
	) );

	// This theme uses a custom image size for featured images, displayed on "standard" posts.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 1200, 800 ); // Unlimited height, soft crop
	add_image_size( 'slider-image', 1200, 600, true ); // Sets slider image size
	add_image_size( 'banner-thumb',547, 130, true ); // Sets banner image size
	add_image_size( 'recent-thumb',100, 80, true ); // Sets banner image size

	// Indicate widget sidebars can use selective refresh in the Customizer.
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	// Add site logo
	add_theme_support( 'custom-logo', array(
		'height'      => 133,
		'width'       => 400,
		'flex-width' => true,
		'flex-height' => true,
	) );
	
	/**
 	 * Adding support for WooCommerce 3.0’s new gallery feature to your theme
 	 */
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
	
}
add_action( 'after_setup_theme', 'makena_setup' );

function makena_the_custom_logo() {
	
	if ( function_exists( 'the_custom_logo' ) ) {
		the_custom_logo();
	}
}

/**
 * Load theme's init file
 */
require( get_template_directory() . '/inc/init.php' );

/**
 * Remove white space above header
 */
function remove_admin_bar() {
	$current_user = wp_get_current_user();
	if (user_can( $current_user, 'administrator' ) ) { ?>
  		<style>
        	html { margin-top: 32px !important; }
        </style>
	<?php } else {
        add_theme_support( 'admin-bar', array( 'callback' => '__return_false' ) );
	}
}

/**
 * Return the Google font stylesheet URL if available.
 *
 * @since Makena 1.2
 *
 * @return string Font stylesheet or empty string if disabled.
 */
function makena_get_font_url() {
	$font_url = '';

	/* translators: If there are characters in your language that are not supported
	 * by Open Sans, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Open Sans and Sacramento fonts: on or off', 'makena' ) ) {
		$subsets = 'latin,latin-ext';

		/* translators: To add an additional Open Sans character subset specific to your language,
		 * translate this to 'greek', 'cyrillic' or 'vietnamese'. Do not translate into your own language.
		 */
		$subset = _x( 'no-subset', 'Open Sans and Sacramento fonts: add new subset (greek, cyrillic, vietnamese)', 'makena' );

		if ( 'cyrillic' == $subset )
			$subsets .= ',cyrillic,cyrillic-ext';
		elseif ( 'greek' == $subset )
			$subsets .= ',greek,greek-ext';
		elseif ( 'vietnamese' == $subset )
			$subsets .= ',vietnamese';

		$query_args = array(
			'family' => 'Open+Sans:400italic,700italic,400,700|Sacramento:400',
			'subset' => $subsets,
		);
		$font_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return $font_url;
}

/**
 * Enqueue scripts and styles for front end.
 *
 * @since Makena 1.0
 */
function makena_scripts_styles() {
	global $wp_styles;

	/*
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	// Adds JavaScript for handling the navigation menu hide-and-show behavior.
	wp_enqueue_script( 'makena-navigation', get_template_directory_uri() . '/js/navigation.js', array( 'jquery' ), '20140711', true );
	
	// Adds JavaScript for handling gallery metabox, Flexslider
	wp_enqueue_script( 'makena-global', get_template_directory_uri() . '/js/global.js', array( 'jquery' ), '20160414', true );
	
	// Adds JavaScript for handling Flexslider
	wp_enqueue_script( 'flexslider-js', get_template_directory_uri() . '/js/jquery.flexslider-min.js', array( 'jquery' ), '20160414', true );

	$font_url = makena_get_font_url();
	if ( ! empty( $font_url ) )
		wp_enqueue_style( 'makena-fonts', esc_url_raw( $font_url ), array(), null );

	// Loads our main style sheet.
	wp_enqueue_style( 'makena-style', get_stylesheet_uri() );
	
	// Loads features stylesheet.
	wp_enqueue_style( 'makena-features', get_template_directory_uri() . '/css/features.css', '20171017' );

	// Loads grid system stylesheet.
	wp_enqueue_style( 'makena-base', get_template_directory_uri() . '/css/base.css', '20171017' );
	
	// Loads widgets style sheet.
	wp_enqueue_style( 'makena-widgets-css', get_template_directory_uri() . '/css/cgg-widgets.css', '20180427' );
	
	// Loads responsive style sheet.
	wp_enqueue_style( 'makena-responsive', get_template_directory_uri() . '/css/responsive.css', '20171017' );

	// Loads the Internet Explorer specific stylesheet.
	wp_enqueue_style( 'makena-ie', get_template_directory_uri() . '/css/ie.css', array( 'makena-style' ), '20121010' );
	$wp_styles->add_data( 'makena-ie', 'conditional', 'lt IE 9' );
	
	// Loads MailChimp stylesheet.
	wp_enqueue_style( 'makena-newsletter', get_template_directory_uri() . '/css/newsletter.css', '20171017' );

	// Loads Contact Form 7 style sheet.
	wp_enqueue_style( 'makena-wpcf7', get_template_directory_uri() . '/css/wpcf7.css', '20171017' );
	
	// Loads the style sheet for Flexslider.
	wp_enqueue_style( 'flexslider', get_template_directory_uri() . '/css/flexslider.css' );
	
	// Loads the style sheet for Flexslider.
	wp_enqueue_style( 'custom-flexslider', get_template_directory_uri() . '/css/custom-slider.css' );
	
}
add_action( 'wp_enqueue_scripts', 'makena_scripts_styles' );

/*
 * Add Fontawesome styles
 */
function font_awesome_styles() {
	wp_enqueue_style( 'font-awesome-free', '//use.fontawesome.com/releases/v5.8.1/css/all.css' );
	wp_enqueue_style( 'Font-awesome', '//maxcdn.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.min.css' );
}
add_action( 'wp_enqueue_scripts', 'font_awesome_styles' );

/**
 * Add preconnect for Google Fonts.
 *
 * @since Makena 1.0
 */
function makena_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'makena-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		if ( version_compare( $GLOBALS['wp_version'], '4.7-alpha', '>=' ) ) {
			$urls[] = array(
				'href' => 'https://fonts.gstatic.com',
				'crossorigin',
			);
		} else {
			$urls[] = 'https://fonts.gstatic.com';
		}
	}

	return $urls;
}
add_filter( 'wp_resource_hints', 'makena_resource_hints', 10, 2 );

/**
 * Filter TinyMCE CSS path to include Google Fonts.
 *
 * Adds additional stylesheets to the TinyMCE editor if needed.
 *
 * @uses makena_get_font_url() To get the Google Font stylesheet URL.
 *
 * @since Makena 1.2
 */
function makena_mce_css( $mce_css ) {
	$font_url = makena_get_font_url();

	if ( empty( $font_url ) )
		return $mce_css;

	if ( ! empty( $mce_css ) )
		$mce_css .= ',';

	$mce_css .= esc_url_raw( str_replace( ',', '%2C', $font_url ) );

	return $mce_css;
}
add_filter( 'mce_css', 'makena_mce_css' );

/**
 * Filter the page title.
 *
 * Creates a nicely formatted and more specific title element text
 * for output in head of document, based on current view.
 *
 * @since Makena 1.0
 */
function makena_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name', 'display' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'makena' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'makena_wp_title', 10, 2 );

/**
 * Filter the page menu arguments.
 *
 * Makes our wp_nav_menu() fallback -- wp_page_menu() -- show a home link.
 *
 * @since Makena 1.0
 */
function makena_page_menu_args( $args ) {
	if ( ! isset( $args['show_home'] ) )
		$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'makena_page_menu_args' );

/**
 * Register sidebars.
 *
 * Registers our main widget area and the front page widget areas.
 *
 * @since Makena 1.0
 */
function makena_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'makena' ),
		'id' => 'sidebar-1',
		'description' => __( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'makena' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Shop Page', 'makena' ),
		'id' => 'sidebar-2',
		'description' => __( 'Appears when using the Shop Page template', 'makena' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'makena_widgets_init' );

if ( ! function_exists( 'makena_content_nav' ) ) :
/**
 * Displays navigation to next/previous pages when applicable.
 *
 * @since Makena 1.0
 */
function makena_content_nav( $html_id ) {
	global $wp_query;
	
	$big = 999999999; // need an unlikely integer
	$translated = __( 'Page', 'makena' ); // Supply translatable string
	
	$paginate_links = paginate_links( array(
		'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' => '?paged=%#%',
		'current' => max( 1, get_query_var('paged') ),
		'total' => $wp_query->max_num_pages,
        'before_page_number' => '<span class="screen-reader-text">'.$translated.' </span>'
	) ); 
	
	// Display the pagination if more than one page is found
    if ( ! empty( $paginate_links ) ) {
        echo '<div class="pagination">';
        echo $paginate_links;
        echo '</div>';
    }
}
endif;

/**
 * Filter the except length to 20 words.
 *
 * @param int $length Excerpt length.
 * @return int (Maybe) modified excerpt length.
 */
add_filter( 'excerpt_length', 'makena_excerpt_length' );
function makena_excerpt_length( $length ) {
	return get_theme_mod( 'makena_excerpt_length', 20 );
}

// Replaces the excerpt "Read More" text by a link
function custom_excerpt_more($more) {
       global $post;
		return '<div class="read-more-button"><a class="moretag" href="'. get_permalink($post->ID) . '"> Continue reading </a></div>';
}
add_filter('excerpt_more', 'custom_excerpt_more');

if ( ! function_exists( 'makena_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own makena_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Makena 1.0
 */
function makena_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<p><?php _e( 'Pingback:', 'makena' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'makena' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<header class="comment-meta comment-author vcard">
				<?php
					echo get_avatar( $comment, 44 );
					printf( '<cite><b class="fn">%1$s</b> %2$s</cite>',
						get_comment_author_link(),
						// If current post author is also comment author, make it known visually.
						( $comment->user_id === $post->post_author ) ? '<span>' . __( 'Post author', 'makena' ) . '</span>' : ''
					);
					printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
						esc_url( get_comment_link( $comment->comment_ID ) ),
						get_comment_time( 'c' ),
						/* translators: 1: date, 2: time */
						sprintf( __( '%1$s at %2$s', 'makena' ), get_comment_date(), get_comment_time() )
					);
				?>
			</header><!-- .comment-meta -->

			<?php if ( '0' == $comment->comment_approved ) : ?>
				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'makena' ); ?></p>
			<?php endif; ?>

			<section class="comment-content comment">
				<?php comment_text(); ?>
				<?php edit_comment_link( __( 'Edit', 'makena' ), '<p class="edit-link">', '</p>' ); ?>
			</section><!-- .comment-content -->

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'makena' ), 'after' => ' <span>&darr;</span>', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}
endif;

if ( ! function_exists( 'makena_entry_meta' ) ) :
/**
 * Set up post entry meta.
 *
 * Prints HTML with meta information for current post: categories, tags, permalink, author, and date.
 *
 * Create your own makena_entry_meta() to override in a child theme.
 *
 * @since Makena 1.0
 */
function makena_entry_meta() {
	// Translators: used between list items, there is a space after the comma.
	$categories_list = get_the_category_list( __( ', ', 'makena' ) );

	// Translators: used between list items, there is a space after the comma.
	$tag_list = get_the_tag_list( '', __( ', ', 'makena' ) );

	$date = sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>',
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() )
	);

	$author = sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'makena' ), get_the_author() ) ),
		get_the_author()
	);

	// Translators: 1 is category, 2 is tag, 3 is the date and 4 is the author's name.
	if ( $tag_list ) {
		$utility_text = __( '<span class="cat">%1$s</span> <span class="tagged">%2$s</span> <span class="post_date">%3$s</span> <span class="by-author">%4$s</span>', 'makena' );
	} elseif ( $categories_list ) {
		$utility_text = __( '<span class="cat">%1$s</span> <span class="post_date">%3$s</span> <span class="by-author">%4$s</span>', 'makena' );
	} else {
		$utility_text = __( '<span class="post_date">%3$s</span> <span class="by-author">%4$s</span>', 'makena' );
	}

	printf(
		$utility_text,
		$categories_list,
		$tag_list,
		$date,
		$author
	);
}
endif;

/**
 * Extend the default WordPress body classes.
 *
 * Extends the default WordPress body class to denote:
 * 1. Using a full-width layout, when no active widgets in the sidebar
 *    or full-width template.
 * 2. Front Page template: thumbnail in use and number of sidebars for
 *    widget areas.
 * 3. White or empty background color to change the layout and spacing.
 * 4. Custom fonts enabled.
 * 5. Single or multiple authors.
 *
 * @since Makena 1.0
 */
function makena_body_class( $classes ) {
	$background_color = get_background_color();
	$background_image = get_background_image();

	if ( ! is_active_sidebar( 'sidebar-1' ) || is_page_template( 'page-templates/full-width.php' ) || is_page_template( 'page-templates/columns-page.php' ) )
		$classes[] = 'full-width';

	if ( is_page_template( 'page-templates/front-page.php' ) ) {
		$classes[] = 'template-front-page';
		if ( has_post_thumbnail() )
			$classes[] = 'has-post-thumbnail';
		if ( is_active_sidebar( 'sidebar-2' ) )
			$classes[] = 'shop-sidebar';
	}

	if ( empty( $background_image ) ) {
		if ( empty( $background_color ) )
			$classes[] = 'custom-background-empty';
		elseif ( in_array( $background_color, array( 'fff', 'ffffff' ) ) )
			$classes[] = 'custom-background-white';
	}

	// Enable custom font class only if the font CSS is queued to load.
	if ( wp_style_is( 'makena-fonts', 'queue' ) )
		$classes[] = 'custom-font-enabled';

	if ( ! is_multi_author() )
		$classes[] = 'single-author';
		
		// Switch sidebar to left
	if ( 'left' === get_theme_mod( 'sidebar_position', 'right' ) ) {
		$classes[] = 'left-sidebar';
	}
	
	// Change page layout to list columns
	if ( 'list' === get_theme_mod( 'makena_blog_layout', 'list' ) ) {
		$classes[] = 'entry-list';
	}
	
	if ( 'classic' === get_theme_mod( 'makena_blog_layout', 'classic' ) ) {
		$classes[] = 'classic';
	}

	return $classes;
}
add_filter( 'body_class', 'makena_body_class' );

/**
 * Adjust content width in certain contexts.
 *
 * Adjusts content_width value for full-width and single image attachment
 * templates, and when there are no active widgets in the sidebar.
 *
 * @since Makena 1.0
 */
function makena_content_width() {
	if ( is_page_template( 'page-templates/full-width.php' ) || is_attachment() || ! is_active_sidebar( 'sidebar-1' ) || is_page_template( 'page-templates/columns-page.php' ) ) {
		global $content_width;
		$content_width = 1200;
	}
}
add_action( 'template_redirect', 'makena_content_width' );

/**
 * Share post content from your site
 *
 * @since Makena 1.2
 */
function post_social_share() {

	if( is_single() ) { ?>
		<ul class="post-entry-socials">
			<?php
			
			global $post;
		
			$url = urlencode(get_permalink());
			$title = str_replace(' ', '%20', get_the_title());
			$blog_title = get_bloginfo('name');
			$target = 'target="_blank"';
		
			$facebook = add_query_arg( array(
				'url' => get_permalink(),
			), 'https://www.facebook.com/sharer.php' );

			$twitter = add_query_arg( array(
				'url' => get_permalink(),
			), 'https://twitter.com/share' );

			$pinterest = add_query_arg( array(
				'url'         => get_permalink(),
				'description' => get_the_title(),
			), 'https://pinterest.com/pin/create/bookmarklet/' );
			
			$linkedin = add_query_arg( array(
				'url'         => get_permalink(),
				'description' => get_the_title(),
			), 'https://linkedin.com/shareArticle' );
			
			$whatsapp = add_query_arg( array(
				'url'         => get_permalink(),
				'description' => get_the_title(),
			), 'href="whatsapp://send?text='.$title.' '.$url.'"' );
		?>
		<li><a target="_blank" href="<?php echo esc_url( $facebook ); ?>" <?php echo $target; ?> class="social-icon"><i class="fa fa-facebook"></i></a></li>
		<li><a target="_blank" href="<?php echo esc_url( $twitter ); ?>" <?php echo $target; ?> class="social-icon"><i class="fa fa-twitter"></i></a></li>
		<li><a target="_blank" href="<?php echo esc_url( $pinterest ); ?>" <?php echo $target; ?> class="social-icon"><i class="fa fa-pinterest"></i></a></li>
		<li><a target="_blank" href="<?php echo esc_url( $linkedin ); ?>" <?php echo $target; ?> class="social-icon"><i class="fa fa-linkedin"></i></a></li>
		<li><a target="_blank" href="<?php echo esc_url( $whatsapp ); ?>" <?php echo $target; ?> class="social-icon"><i class="fa fa-whatsapp"></i></a></li>
	</ul>
		<?php } else { ?>
		<?php // if not a post/page then don't include sharing button
				
		} ?>
<?php }

/**
 * Show Share Icons on blog page for entry list
 *
 * @since Makena 1.2
 */
 function entry_list_share() { ?>
 	<ul class="entry-list-socials">
		<?php
			
			global $post;
		
			$url = urlencode(get_permalink());
			$title = str_replace(' ', '%20', get_the_title());
			$blog_title = get_bloginfo('name');
			$target = 'target="_blank"';
		
			$facebook = add_query_arg( array(
				'url' => get_permalink(),
			), 'https://www.facebook.com/sharer.php' );

			$twitter = add_query_arg( array(
				'url' => get_permalink(),
			), 'https://twitter.com/share' );

			$pinterest = add_query_arg( array(
				'url'         => get_permalink(),
				'description' => get_the_title(),
			), 'https://pinterest.com/pin/create/bookmarklet/' );
			
			$linkedin = add_query_arg( array(
				'url'         => get_permalink(),
				'description' => get_the_title(),
			), 'https://linkedin.com/shareArticle' );
			
			$whatsapp = add_query_arg( array(
				'url'         => get_permalink(),
				'description' => get_the_title(),
			), 'href="whatsapp://send?text='.$title.' '.$url.'"' );
		?>
		<li><a target="_blank" href="<?php echo esc_url( $facebook ); ?>" <?php echo $target; ?> class="social-icon"><i class="fa fa-facebook"></i></a></li>
		<li><a target="_blank" href="<?php echo esc_url( $twitter ); ?>" <?php echo $target; ?> class="social-icon"><i class="fa fa-twitter"></i></a></li>
		<li><a target="_blank" href="<?php echo esc_url( $pinterest ); ?>" <?php echo $target; ?> class="social-icon"><i class="fa fa-pinterest"></i></a></li>
		<li><a target="_blank" href="<?php echo esc_url( $linkedin ); ?>" <?php echo $target; ?> class="social-icon"><i class="fa fa-linkedin"></i></a></li>
		<li><a target="_blank" href="<?php echo esc_url( $whatsapp ); ?>" <?php echo $target; ?> class="social-icon"><i class="fa fa-whatsapp"></i></a></li>
	</ul>
<?php  }

/*
 * Remove p tags from iframes
 *
 * Source: https://gist.github.com/KTPH/7901c0d2c66dc2d754ce
 */
function filter_ptags_on_images_iframes($content) {
    $content = preg_replace('/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(<\/a>)?\s*<\/p>/iU', '\1\2\3', $content);
    return preg_replace('/<p>\s*(<iframe .*>*.<\/iframe>)\s*<\/p>/iU', '\1', $content);
}
add_filter('the_content', 'filter_ptags_on_images_iframes');

/* 
 * Fallback images for posts 
 */
function cgg_post_thumbnail_fallback( $html, $post_id, $post_thumbnail_id, $size, $attr ) {
    if ( empty( $html ) ) {
        return sprintf(
            '<img class="cgg_fallback_img" src="%s" height="%s" width="%s" />',
            get_template_directory_uri().'/images/1.jpg',
            get_option( 'thumbnail_size_w' ),
            get_option( 'thumbnail_size_h' )
        );
    }

    return $html;
}
add_filter( 'post_thumbnail_html', 'cgg_post_thumbnail_fallback', 20, 5 );

/**
 * Limit Amount of Primary Menu Items in WordPress
 *
 * @since Makena 1.0
 */
add_filter( 'wp_nav_menu_objects', 'cgg_primary_menufilter', 10, 2 );
function cgg_primary_menufilter($items, $args) {
    if ( $args->theme_location == 'primary' ) {
        $toplinks = 0;
        foreach ( $items as $k => $v ) {
            if ( $v->menu_item_parent == 0 ) {
                $toplinks++;
            }
            if ( $toplinks > 4 ) {
                unset($items[$k]);
            }
        }
    }
    return $items;
}

/**
 * Limit Amount of Secondary Menu Items in WordPress
 *
 * @since Makena 1.0
 */
add_filter( 'wp_nav_menu_objects', 'cgg_secondary_menufilter', 10, 2 );
function cgg_secondary_menufilter($items, $args) {
    if ( $args->theme_location == 'secondary' ) {
        $toplinks = 0;
        foreach ( $items as $k => $v ) {
            if ( $v->menu_item_parent == 0 ) {
                $toplinks++;
            }
            if ( $toplinks > 4 ) {
                unset($items[$k]);
            }
        }
    }
    return $items;
}
